import QtQuick 1.1
import "Diagnostics"

ModalDialog{
    id: firmwareUpdatingDialog

    property alias text: bootLoadStatusText.text
    property alias instructionText: instructionText.text
    property int _retryCounter: 0

    signal complete()

    width: 950
    height: 450

    anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: parent.verticalCenter }

    state: "searching_state"

    onStateChanged: {
        if(state == "completed_state") {
            _retryCounter = 0
        }
    }

    BorderImage {   // pop-up dialog background
        id: borderImage

        anchors.fill: parent
        source: "graphics/Pop_Up_Lrg_Grey.png"
        border { top: 152; bottom: 165; left: 145; right: 144 }

        Text{
            id: bootLoadStatusText
            text:""
            color: "white"
            font { bold: true ; pixelSize: 50 }
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            anchors { horizontalCenter: parent.horizontalCenter ; bottom: bootloadProgress.top ; bottomMargin: 5 }
        }

        Text{
            id: instructionText
            text:""
            color: "white"
            font { bold: true ; pixelSize: 50 }
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            anchors { horizontalCenter: parent.horizontalCenter ; top: bootLoadStatusText.bottom ; topMargin: 5 }
        }

        ProgressBar {
            id: bootloadProgress
            property bool isFaulted: false
            visible: firmwareLoader.progress > 0 && isFaulted == false
            width: 400
            height: isFaulted == false ? 50 : 0
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            value: firmwareLoader.progress

        }
    }

    // Timer to allow removal of USB before loading to allow one to change one's mind
    Timer {
        id: waitToLoadTimer
        interval: 5000
        repeat: false
        running: false
        onTriggered: {
            firmwareLoader.loadFirmware(firmwareLoader.firmwareUpdateFile)
            running = false
        }
    }

    FirmwareLoader {
        id: firmwareLoader

        onFaultMsg:{
            _retryCounter++
            bootloadProgress.isFaulted = true
            firmwareUpdatingDialog.text = message
            firmwareUpdatingDialog.state = "completed_with_error_state"
        }
        onStatus: firmwareUpdatingDialog.text = message

        onUpdateStarted: firmwareUpdatingDialog.state = "loading_state"
        onUpdateFinished: firmwareUpdatingDialog.state = "completed_state"

        onFirmwareFound: {
            firmwareUpdatingDialog.state = "waiting_state"
        }
    }

    states: [
        State {
            name: "searching_state"
            PropertyChanges{ target: firmwareUpdatingDialog ; text: qsTr("Fault CN25: Firmware Mismatch") }
        },
        State {
            name: "waiting_state"
            PropertyChanges{
                target: firmwareUpdatingDialog ;
                instructionText: qsTr("Load") + " " + firmwareLoader.firmwareUpdateVersion + ". "
            }
            PropertyChanges{ target: waitToLoadTimer; running: true }
        },
        State {
            name: "loading_state"
            PropertyChanges{ target: firmwareUpdatingDialog ; instructionText: "" }
            PropertyChanges{ target: waitToLoadTimer; running: false }            
            PropertyChanges{ target: bootloadProgress; isFaulted: false }
        },
        State {
            name: "completed_state"
            PropertyChanges{ target: firmwareUpdatingDialog ; instructionText: qsTr("Power Cycle Required.")  }
            PropertyChanges{ target: waitToLoadTimer; running: false }
            PropertyChanges{ target: bootloadProgress; isFaulted: false }

        },
        State {
            name: "completed_with_error_state"
            PropertyChanges{ target: firmwareUpdatingDialog ; instructionText: _retryCounter == 3 ? qsTr("Power Cycle Required.") : qsTr("Retrying...")}
            PropertyChanges{ target: waitToLoadTimer; running: _retryCounter == 3 ? false : true }
            PropertyChanges{ target: bootloadProgress; isFaulted: true }
        }

    ]
}

