// VideoFrame - Aspect ratio corrected video overlay
//  Set frame and fullscreenFrame to allow toggle between frames with the fullscreen property.
import QtQuick 1.1
import VideoOverlay 1.0

VideoOverlay {
    id: root

    property real aspect: 1.3333
    property bool fullscreen  // set to true to expand into fullscreenFrame

    property variant frame // non-fullscreen frame
    property variant fullscreenFrame
    property variant currentFrame: fullscreen ? fullscreenFrame : frame

    // aspect ratio video size calculation.  If currentFrame is undefined, resort to zero size.
    property bool _fullHeight: currentFrame ? (( aspect * currentFrame.height) < currentFrame.width) : 0
    property int videoWidth: currentFrame ? (_fullHeight ? (currentFrame.height * aspect) : currentFrame.width) : 0
    property int videoHeight: currentFrame ? (_fullHeight ? (currentFrame.height) : (currentFrame.width / aspect )) :0

    signal clicked() // video clicked

    onCurrentFrameChanged: {
        if(!currentFrame)
            root.parent = main
        else
            root.parent = currentFrame
    }

    // hide when frame is not defined, hidden or fully transparent
    visible: currentFrame ? (currentFrame.visible && (currentFrame.opacity > 0)) : false
    opacity: currentFrame ? currentFrame.opacity : 0.0
    width: root.videoWidth
    height: root.videoHeight

    MouseArea {
        anchors.fill: parent
        onClicked: root.clicked()
    }
}
